@@ -11,6 +11,8 @@ preinference_input = {}
 # input for modeling
 # https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateHyperParameterTuningJob.html
 tuning_input = {}
+# https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateTrainingJob.html
+training_input = {}
 
 # input for inference
 # https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateModel.html
@@ -30,4 +32,4 @@ prediction_transformer_input = {}
 # input for reporting
 # https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateProcessingJob.html
 testing_input = {}
-reporting_input = {}
\ No newline at end of file
+reporting_input = {}
