@@ -1,7 +1,6 @@
 import unittest
 import json
-
-import aws_mlops.get_best_job as bj
+from aws_mlops.get_best_job import GetBestJob
 
 class SmClient():
     dtj = None
@@ -12,22 +11,23 @@ class SmClient():
         if isinstance(TrainingJobName, str):
             return self.dtj
 
-class TestGetBestJob(unittest.TestCase):
+class TestGetBestJob(unittest.TestCase, GetBestJob):
+    gbj = None
     si = None
     sm = None
 
     def __init__(self, *args, **kwargs):
-        bj.sm = SmClient()
+        self.gbj = GetBestJob()
+        self.gbj.sm = SmClient()
         with open('tests/sm-step-input.json') as json_file:
             self.si = json.load(json_file)
         unittest.TestCase.__init__(self, *args, **kwargs)
     
-    def test_main(self):
-        result = bj.main(self.si, None)
-        self.assertEqual(result['statusCode'], 200)
-        self.assertEqual(result['body']['HyperParameter']['eval_metric'], 'rmse')
-        self.assertEqual(result['body']['test_input']['key'], 'value')
-        self.assertEqual(result['body']['TrainingJobName'], 'test')
+    def test_run(self):
+        result = self.gbj.run(self.si)
+        self.assertEqual(result['HyperParameter']['eval_metric'], 'rmse')
+        self.assertEqual(result['test_input']['key'], 'value')
+        self.assertEqual(result['TrainingJobName'], 'test')
 
 if __name__ == '__main__':
     unittest.main()
\ No newline at end of file
